@@ -116,9 +116,11 @@ struct ParserClass {
         auto r = a.mutable_unchecked();
         for (py::ssize_t i=0; i<r.shape(0); i++) {
             auto element = pParser->getMetric(metricNames[i]);
-            for (py::ssize_t j=0; j<r.shape(1); j++) {
-                r(i,j) = element->at(j);
-            }
+            if (element)
+
+                for (py::ssize_t j=0; j<r.shape(1); j++) {
+                    r(i,j) = element->at(j);
+                }
         }
         return a;
     }
